## Summary

<!-- What does this PR do and why? -->

## Changes

-

## Test Plan

- [ ] All existing tests pass (`pytest`)
- [ ] Added/updated tests for new behavior
- [ ] Generated a project and verified output (`djsuite testproject --dry-run`)
